@@ -25,8 +25,8 @@
 
 #include <powerdevilbackendinterface.h>
 
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusInterface>
+#include <QDBusConnection>
+#include <QDBusInterface>
 
 #include "upower_device_interface.h"
 #include "upower_interface.h"
@@ -42,8 +42,6 @@
 #define CONSOLEKIT2_SERVICE "org.freedesktop.ConsoleKit"
 
 class UdevHelper;
-class XRandRXCBHelper;
-class XRandrBrightness;
 class QPropertyAnimation;
 class DDCutilBrightness;
 class Q_DECL_EXPORT PowerDevilUPowerBackend : public PowerDevil::BackendInterface
@@ -54,17 +52,17 @@ class Q_DECL_EXPORT PowerDevilUPowerBackend : public PowerDevil::BackendInterfac
 
 public:
     explicit PowerDevilUPowerBackend(QObject* parent = nullptr);
-    virtual ~PowerDevilUPowerBackend();
+    ~PowerDevilUPowerBackend() override;
 
-    void init() Q_DECL_OVERRIDE;
+    void init() override;
     static bool isAvailable();
 
-    int brightness(BrightnessControlType type = Screen) const Q_DECL_OVERRIDE;
-    int brightnessMax(BrightnessControlType type = Screen) const Q_DECL_OVERRIDE;
+    int brightness(BrightnessControlType type = Screen) const override;
+    int brightnessMax(BrightnessControlType type = Screen) const override;
 
-    int brightnessKeyPressed(PowerDevil::BrightnessLogic::BrightnessKeyType type, BrightnessControlType controlType) Q_DECL_OVERRIDE;
-    void setBrightness(int value, PowerDevil::BackendInterface::BrightnessControlType type = Screen) Q_DECL_OVERRIDE;
-    KJob* suspend(PowerDevil::BackendInterface::SuspendMethod method) Q_DECL_OVERRIDE;
+    int brightnessKeyPressed(PowerDevil::BrightnessLogic::BrightnessKeyType type, BrightnessControlType controlType) override;
+    void setBrightness(int value, PowerDevil::BackendInterface::BrightnessControlType type = Screen) override;
+    KJob* suspend(PowerDevil::BackendInterface::SuspendMethod method) override;
 
 Q_SIGNALS:
     void brightnessSupportQueried(bool available);
@@ -99,8 +97,6 @@ private:
 
     // brightness
     QMap<BrightnessControlType, int> m_cachedBrightnessMap;
-    XRandrBrightness         *m_brightnessControl;
-    XRandRXCBHelper *m_randrHelper;
     DDCutilBrightness *m_ddcBrightnessControl;
 
     OrgFreedesktopUPowerInterface *m_upowerInterface;
